@@ -1,5 +1,5 @@
 package Mira::View::Floor;
-$Mira::View::Floor::VERSION = '00.07.38';
+$Mira::View::Floor::VERSION = '00.07.40';
 
 use strict;
 use warnings;
@@ -55,9 +55,9 @@ sub template {
             INCLUDE_PATH => [ $floor_template_root, catdir($floor_template_root, 'include') ],
             INTERPOLATE  => 1,
             ENCODING => 'utf8',
-            START_TAG => quotemeta('{{'),
-            END_TAG   => quotemeta('}}'),
-            OUTLINE_TAG => '{%',
+            START_TAG => quotemeta($config->{$floor}->{t_start_tag}),
+            END_TAG   => quotemeta($config->{$floor}->{t_end_tag}),
+            OUTLINE_TAG => quotemeta( $config->{$floor}->{t_outline_tag} ),
           }) || die "$Template::ERROR\n";
 
         my $vars = {
