@@ -1,5 +1,5 @@
 package Mira::View::Main;
-$Mira::View::Main::VERSION = '00.07.38';
+$Mira::View::Main::VERSION = '00.07.40';
 
 use strict;
 use warnings;
@@ -23,8 +23,12 @@ sub template {
   my $build = $switches{build};
 
   my $template_root;
-
-  if (defined $config->{_default}->{template} and -f catfile($pensource,'template', $config->{_default}->{template}, 'main.tt2') )
+  if
+  (
+  (exists $config->{_default}->{template})
+   and
+  ( -f catfile($pensource,'template', $config->{_default}->{template}, 'main.tt2') )
+  )
   {
     $template_root = catdir($pensource,'template', $config->{_default}->{template});
   } else
@@ -36,8 +40,9 @@ sub template {
       INCLUDE_PATH => [$template_root, catdir($template_root, 'include') ],
       INTERPOLATE  => 1,
       ENCODING => 'utf8',
-      START_TAG => quotemeta('{{'),
-      END_TAG   => quotemeta('}}'),
+      START_TAG => quotemeta($config->{_default}->{t_start_tag}),
+      END_TAG   => quotemeta($config->{_default}->{t_end_tag}),
+      OUTLINE_TAG => quotemeta( $config->{_default}->{t_outline_tag} ),
   }) || die "$Template::ERROR\n";
 
   my $vars = {
